@@ -11,22 +11,41 @@ module Jekyll
         @parser =
           case @config['markdown'].downcase
             when 'redcarpet' then RedcarpetParser.new(@config)
-            when 'kramdown' then KramdownParser.new(@config)
+            when 'kramdown'  then KramdownParser.new(@config)
             when 'rdiscount' then RDiscountParser.new(@config)
-            when 'maruku' then MarukuParser.new(@config)
+            when 'maruku'    then MarukuParser.new(@config)
           else
             # So they can't try some tricky bullshit or go down the ancestor chain, I hope.
             if allowed_custom_class?(@config['markdown'])
               self.class.const_get(@config['markdown']).new(@config)
             else
               Jekyll.logger.error "Invalid Markdown Processor:", "#{@config['markdown']}"
-              Jekyll.logger.error "", "Valid options are [ maruku | rdiscount | kramdown | redcarpet ]"
-              raise FatalException, "Invalid Markdown Processor: #{@config['markdown']}"
+              Jekyll.logger.error "", "Valid options are [ #{valid_processors.join(" | ")} ]"
+              raise Errors::FatalException, "Invalid Markdown Processor: #{@config['markdown']}"
             end
           end
         @setup = true
       end
 
+      def valid_processors
+        %w[
+          maruku
+          rdiscount
+          kramdown
+          redcarpet
+        ] + third_party_processors
+      end
+
+      def third_party_processors
+        self.class.constants - %w[
+          KramdownParser
+          MarukuParser
+          RDiscountParser
+          RedcarpetParser
+          PRIORITIES
+        ].map(&:to_sym)
+      end
+
       def matches(ext)
         rgx = '^\.(' + @config['markdown_ext'].gsub(',','|') +')$'
         ext =~ Regexp.new(rgx, Regexp::IGNORECASE)
