@@ -8,7 +8,7 @@ module Jekyll
         rescue LoadError
           STDERR.puts 'You are missing a library required for Markdown. Please run:'
           STDERR.puts '  $ [sudo] gem install kramdown'
-          raise FatalException.new("Missing dependency: kramdown")
+          raise Errors::FatalException.new("Missing dependency: kramdown")
         end
 
         def convert(content)
