@@ -13,7 +13,7 @@ module Jekyll
       rescue LoadError
         STDERR.puts 'You are missing a library required for Textile. Please run:'
         STDERR.puts '  $ [sudo] gem install RedCloth'
-        raise FatalException.new("Missing dependency: RedCloth")
+        raise Errors::FatalException.new("Missing dependency: RedCloth")
       end
 
       def matches(ext)
@@ -32,7 +32,7 @@ module Jekyll
         return RedCloth.new(content).to_html if @config['redcloth'].nil?
 
         # List of attributes defined on RedCloth
-        # (from http://redcloth.rubyforge.org/classes/RedCloth/TextileDoc.html)
+        # (from https://github.com/jgarber/redcloth/blob/master/lib/redcloth/textile_doc.rb)
         attrs = ['filter_classes', 'filter_html', 'filter_ids', 'filter_styles',
                 'hard_breaks', 'lite_mode', 'no_span_caps', 'sanitize_html']
 
