@@ -43,7 +43,7 @@ module Jekyll
     # Returns nothing.
     def read_yaml(base, name, opts = {})
       begin
-        self.content = File.read(File.join(base, name),
+        self.content = File.read(Jekyll.sanitized_path(base, name),
                                  merged_file_read_opts(opts))
         if content =~ /\A(---\s*\n.*?\n?)^((---|\.\.\.)\s*$\n?)/m
           self.content = $POSTMATCH
@@ -114,6 +114,10 @@ module Jekyll
       Utils.deep_merge_hashes defaults, Utils.deep_merge_hashes(data, further_data)
     end
 
+    # The type of a document,
+    #   i.e., its classname downcase'd and to_sym'd.
+    #
+    # Returns the type of self.
     def type
       if is_a?(Post)
         :post
@@ -124,6 +128,40 @@ module Jekyll
       end
     end
 
+    # Determine whether the document is an asset file.
+    # Asset files include CoffeeScript files and Sass/SCSS files.
+    #
+    # Returns true if the extname belongs to the set of extensions
+    #   that asset files use.
+    def asset_file?
+      %w[.sass .scss .coffee].include?(ext)
+    end
+
+    # Determine whether the file should be rendered with Liquid.
+    #
+    # Returns false if the document is either an asset file or a yaml file,
+    #   true otherwise.
+    def render_with_liquid?
+      !asset_file?
+    end
+
+    # Determine whether the file should be placed into layouts.
+    #
+    # Returns false if the document is either an asset file or a yaml file,
+    #   true otherwise.
+    def place_in_layout?
+      !asset_file?
+    end
+
+    # Checks if the layout specified in the document actually exists
+    #
+    # layout - the layout to check
+    #
+    # Returns true if the layout is invalid, false if otherwise
+    def invalid_layout?(layout)
+      !data["layout"].nil? && data["layout"] != "none" && layout.nil? && !(self.is_a? Jekyll::Excerpt)
+    end
+
     # Recursively render layouts
     #
     # layouts - a list of the layouts
@@ -134,6 +172,9 @@ module Jekyll
     def render_all_layouts(layouts, payload, info)
       # recursively render layouts
       layout = layouts[data["layout"]]
+
+      Jekyll.logger.warn("Build Warning:", "Layout '#{data["layout"]}' requested in #{path} does not exist.") if invalid_layout? layout
+
       used = Set.new([layout])
 
       while layout
@@ -167,13 +208,13 @@ module Jekyll
       payload["highlighter_prefix"] = converter.highlighter_prefix
       payload["highlighter_suffix"] = converter.highlighter_suffix
 
-      self.content = render_liquid(content, payload, info)
+      self.content = render_liquid(content, payload, info) if render_with_liquid?
       transform
 
       # output keeps track of what will finally be written
       self.output = content
 
-      render_all_layouts(layouts, payload, info)
+      render_all_layouts(layouts, payload, info) if place_in_layout?
     end
 
     # Write the generated page file to the destination directory.
