@@ -193,12 +193,12 @@ module Jekyll
     # Sort an array of objects
     #
     # input - the object array
-    # key - key within each object to filter by
+    # property - property within each object to filter by
     # nils ('first' | 'last') - nils appear before or after non-nil values
     #
     # Returns the filtered array of objects
-    def sort(input, key = nil, nils = "first")
-      if key.nil?
+    def sort(input, property = nil, nils = "first")
+      if property.nil?
         input.sort
       else
         case
@@ -207,18 +207,20 @@ module Jekyll
         when nils == "last"
           order = + 1
         else
-          Jekyll.logger.error "Invalid nils order:",
-            "'#{nils}' is not a valid nils order. It must be 'first' or 'last'."
-          exit(1)
+          raise ArgumentError.new("Invalid nils order: " +
+            "'#{nils}' is not a valid nils order. It must be 'first' or 'last'.")
         end
 
-        input.sort { |a, b|
-          if !a[key].nil? && b[key].nil?
+        input.sort { |apple, orange|
+          apple_property = item_property(apple, property)
+          orange_property = item_property(orange, property)
+
+          if !apple_property.nil? && orange_property.nil?
             - order
-          elsif a[key].nil? && !b[key].nil?
+          elsif apple_property.nil? && !orange_property.nil?
             + order
           else
-            a[key] <=> b[key]
+            apple_property <=> orange_property
           end
         }
       end
@@ -231,7 +233,7 @@ module Jekyll
         input
       when String
         Time.parse(input) rescue Time.at(input.to_i)
-      when Number
+      when Numeric
         Time.at(input)
       else
         Jekyll.logger.error "Invalid Date:", "'#{input}' is not a valid datetime."
@@ -244,7 +246,9 @@ module Jekyll
     end
 
     def item_property(item, property)
-      if item.respond_to?(:data)
+      if item.respond_to?(:to_liquid)
+        item.to_liquid[property.to_s]
+      elsif item.respond_to?(:data)
         item.data[property.to_s]
       else
         item[property.to_s]
