@@ -1,11 +1,13 @@
 module Jekyll
-
   class Layout
     include Convertible
 
     # Gets the Site object.
     attr_reader :site
 
+    # Gets the name of this layout.
+    attr_reader :name
+
     # Gets/Sets the extension of this layout.
     attr_accessor :ext
 
@@ -27,8 +29,8 @@ module Jekyll
 
       self.data = {}
 
-      self.process(name)
-      self.read_yaml(base, name)
+      process(name)
+      read_yaml(base, name)
     end
 
     # Extract information from the layout filename.
@@ -40,5 +42,4 @@ module Jekyll
       self.ext = File.extname(name)
     end
   end
-
 end
