@@ -1,3 +1,5 @@
+# encoding: utf-8
+
 require 'helper'
 
 class TestPost < Test::Unit::TestCase
@@ -74,6 +76,21 @@ class TestPost < Test::Unit::TestCase
         assert_equal "/2008/09/09/foo-bar", @post.id
       end
 
+      should "keep categories" do
+        post = Post.allocate
+        post.site = @site
+        post.process("cat1/2008-09-09-foo-bar.textile")
+        assert_equal 1, post.categories.size
+        assert_equal "cat1", post.categories[0]
+
+        post = Post.allocate
+        post.site = @site
+        post.process("cat2/CAT3/2008-09-09-foo-bar.textile")
+        assert_equal 2, post.categories.size
+        assert_equal "cat2", post.categories[0]
+        assert_equal "cat3", post.categories[1]
+      end
+
       should "create url based on date and title" do
         @post.categories = []
         @post.process(@fake_file)
@@ -81,7 +98,7 @@ class TestPost < Test::Unit::TestCase
       end
 
       should "raise a good error on invalid post date" do
-        assert_raise Jekyll::FatalException do
+        assert_raise Jekyll::Errors::FatalException do
           @post.process("2009-27-03-foo-bar.textile")
         end
       end
@@ -100,6 +117,14 @@ class TestPost < Test::Unit::TestCase
         assert_equal "/2014/03/22/escape-+ %20[]", @post.id
       end
 
+      should "return a UTF-8 escaped string" do
+        assert_equal Encoding::UTF_8, URL.escape_path("/rails笔记/2014/04/20/escaped/").encoding
+      end
+
+      should "return a UTF-8 unescaped string" do
+        assert_equal Encoding::UTF_8, URL.unescape_path("/rails%E7%AC%94%E8%AE%B0/2014/04/20/escaped/".encode(Encoding::ASCII)).encoding
+      end
+
       should "respect permalink in yaml front matter" do
         file = "2008-12-03-permalinked-post.textile"
         @post.process(file)
@@ -450,6 +475,17 @@ class TestPost < Test::Unit::TestCase
         assert_equal Time, post.to_liquid["date"].class
       end
 
+      should "to_liquid should consider inheritance" do
+        klass = Class.new(Jekyll::Post)
+        assert_gets_called = false
+        klass.send(:define_method, :assert_gets_called) { assert_gets_called = true }
+        klass.const_set(:EXCERPT_ATTRIBUTES_FOR_LIQUID, Jekyll::Post::EXCERPT_ATTRIBUTES_FOR_LIQUID + ['assert_gets_called'])
+        post = klass.new(@site, source_dir, '', "2008-02-02-published.textile")
+        do_render(post)
+
+        assert assert_gets_called, 'assert_gets_called did not get called on post.'
+      end
+
       should "recognize category in yaml" do
         post = setup_post("2009-01-27-category.textile")
         assert post.categories.include?('foo')
@@ -594,7 +630,7 @@ class TestPost < Test::Unit::TestCase
 
     should "generate categories and topics" do
       post = Post.new(@site, File.join(File.dirname(__FILE__), *%w[source]), 'foo', 'bar/2008-12-12-topical-post.textile')
-      assert_equal ['foo'], post.categories
+      assert_equal ['foo', 'bar'], post.categories
     end
   end
 
@@ -646,4 +682,60 @@ class TestPost < Test::Unit::TestCase
 
   end
 
+  context "site config with category" do
+    setup do
+      config = Jekyll::Configuration::DEFAULTS.merge({
+        'defaults' => [
+          'scope' => {
+            'path' => ''
+          },
+          'values' => {
+            'category' => 'article'
+          }
+        ]
+      })
+      @site = Site.new(config)
+    end
+
+    should "return category if post does not specify category" do
+      post = setup_post("2009-01-27-no-category.textile")
+      assert post.categories.include?('article'), "Expected post.categories to include 'article' but did not."
+    end
+
+    should "override site category if set on post" do
+      post = setup_post("2009-01-27-category.textile")
+      assert post.categories.include?('foo'), "Expected post.categories to include 'foo' but did not."
+      assert !post.categories.include?('article'), "Did not expect post.categories to include 'article' but it did."
+    end
+  end
+
+  context "site config with categories" do
+    setup do
+      config = Jekyll::Configuration::DEFAULTS.merge({
+        'defaults' => [
+          'scope' => {
+            'path' => ''
+          },
+          'values' => {
+            'categories' => ['article']
+          }
+        ]
+      })
+      @site = Site.new(config)
+    end
+
+    should "return categories if post does not specify categories" do
+      post = setup_post("2009-01-27-no-category.textile")
+      assert post.categories.include?('article'), "Expected post.categories to include 'article' but did not."
+    end
+
+    should "override site categories if set on post" do
+      post = setup_post("2009-01-27-categories.textile")
+      ['foo', 'bar', 'baz'].each do |category|
+        assert post.categories.include?(category), "Expected post.categories to include '#{category}' but did not."
+      end
+      assert !post.categories.include?('article'), "Did not expect post.categories to include 'article' but it did."
+    end
+  end
+
 end
